@@ -1,4 +1,4 @@
-# Copyright 2001-7 by Roger Bivand
+# Copyright 2001-2010 by Roger Bivand
 # Upgrade to sp classes February 2007
 #
 
@@ -11,13 +11,19 @@ nbdists <- function(nb, coords, longlat=NULL) {
 		    && !is.na(is.projected(coords)) && !is.projected(coords)) {
          		longlat <- TRUE
       		} else longlat <- FALSE
-      		coords <- coordinates(coords)
+      		coords <- coordinates(coords)[, 1:2]
    	} else if (is.null(longlat) || !is.logical(longlat)) longlat <- FALSE
 	if (!is.numeric(coords)) stop("Data non-numeric")
 	if (!is.matrix(coords)) 
             stop("Data not in matrix form")
+        stopifnot(ncol(coords) == 2)
         if (any(is.na(coords))) 
             stop("Data include NAs")
+        if (longlat) {
+            bb <- bbox(coords)
+            if (!sp:::.ll_sanity(bb))
+                warning("Coordinates are not geographical: longlat argument wrong")
+        }
 	if (!is.double(coords)) storage.mode(coords) <- "double"
 	n.nb <- length(nb)
 	np <- nrow(coords)
